package com.yiqi.core.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.yiqi.core.domain.GoodsSkuStore;
import com.yiqi.core.domain.vo.GoodsSkuNumDto;
import com.yiqi.system.domain.ManageFactory;
import com.yiqi.system.domain.SysStore;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 商品物料门店关联Mapper接口
 *
 * @author ruoyi
 * @date 2023-09-05
 */
public interface GoodsSkuStoreMapper extends BaseMapper<GoodsSkuStore> {
    /**
     * 查询商品物料门店关联
     *
     * @param id 商品物料门店关联主键
     * @return 商品物料门店关联
     */
    public GoodsSkuStore selectGoodsSkuStoreById(Long id);

    /**
     * 查询商品物料门店关联列表
     *
     * @param goodsSkuStore 商品物料门店关联
     * @return 商品物料门店关联集合
     */
    public List<GoodsSkuStore> selectGoodsSkuStoreList(GoodsSkuStore goodsSkuStore);

    /**
     * 新增商品物料门店关联
     *
     * @param goodsSkuStore 商品物料门店关联
     * @return 结果
     */
    public int insertGoodsSkuStore(GoodsSkuStore goodsSkuStore);

    /**
     * 修改商品物料门店关联
     *
     * @param goodsSkuStore 商品物料门店关联
     * @return 结果
     */
    public int updateGoodsSkuStore(GoodsSkuStore goodsSkuStore);

    /**
     * 删除商品物料门店关联
     *
     * @param id 商品物料门店关联主键
     * @return 结果
     */
    public int deleteGoodsSkuStoreById(Long id);

    /**
     * 批量删除商品物料门店关联
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteGoodsSkuStoreByIds(Long[] ids);

    /**
     * 查询商品物料门店 通过物料id
     *
     * @param skuId 商品物料id
     * @return 商品规格集合
     */
    public List<GoodsSkuStore> getSkuStoreListBySkuId(Long skuId);

    /**
     * 批量新增物料工厂关系
     *
     * @param goodsSkuStore 商品物料门店
     * @return 结果
     */
    public int insertSkuToAllFactory(GoodsSkuStore goodsSkuStore);

    /**
     * 批量新增物料门店关系
     *
     * @param goodsSkuStore 商品物料门店
     * @return 结果
     */
    public int insertSkuToAllStore(GoodsSkuStore goodsSkuStore);

    /**
     * 批量新增工厂和全部商品物料关系
     *
     * @param manageFactory 工厂实例
     * @return 结果
     */
    public int insertFactoryToAllSku(ManageFactory manageFactory);

    /**
     * 批量新增门店和全部商品物料关系
     *
     * @param sysStore 门店实例
     * @return 结果
     */
    public int insertStoreToAllSku(SysStore sysStore);

    /**
     * 更新商品物料库存
     *
     * @param goodsSkuStoreList 更新商品物料库存
     * @return 结果
     */
    public int addGoodsSkuStockByOrderItems(List<GoodsSkuStore> goodsSkuStoreList);

    /**
     * 减去商品物料库存
     *
     * @param goodsSkuStoreList 减去商品物料库存
     * @return 结果
     */
    public int minusGoodsSkuStockByOrder(List<GoodsSkuStore> goodsSkuStoreList);


    /**
     * 查询当前物料库存
     *
     * @param goodsSkuIdList 减去商品物料库存
     * @return 结果
     */
    public List<GoodsSkuStore> getSkuStockByNow(@Param("goodsSkuIdList") List<Long> goodsSkuIdList,
                                                @Param("sourceType") String sourceType,
                                                @Param("orgId") Long orgId);

    /**
     * 减去商品物料库存
     *
     * @param sourceType 减去商品物料库存
     * @param orgId      减去商品物料库存
     * @param skuId      减去商品物料库存
     * @param buyNum     减去商品物料库存
     * @return 结果
     */
    int minusGoodsSkuStockNotCheckByStore(@Param("sourceType") String sourceType, @Param("orgId") Long orgId, @Param("skuId") Long skuId, @Param("buyNum") Integer buyNum);

    /**
     * 减去商品物料库存
     *
     * @param sourceType 减去商品物料库存
     * @param orgId      减去商品物料库存
     * @param skuId      减去商品物料库存
     * @param buyNum     减去商品物料库存
     * @return 结果
     */
    int addGoodsSkuStockNotCheckByStore(@Param("sourceType") String sourceType, @Param("orgId") Long orgId, @Param("skuId") Long skuId, @Param("buyNum") Integer buyNum);


    /**
     * 查询商品sku数量
     *
     * @param goodsId 商品id
     * @return 结果
     */
    public GoodsSkuNumDto getGoodsStoreSkuNumsByGoodsId(@Param("goodsId") Long goodsId, @Param("storeId") Long storeId);
}
